@@ -1,25 +1,28 @@
 from tests.cli_test_case import CliTestCase
 import responses  # type: ignore
 import json
-
+import os
+from unittest import mock
 
 class SessionTest(CliTestCase):
 
     @responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_run_session_without_flavor(self):
         result = self.cli("record", "session", "--build", self.build_name)
         self.assertEqual(result.exit_code, 0)
 
-        payload = json.loads(responses.calls[0].request.body)
+        payload = json.loads(responses.calls[0].request.body.decode())
         self.assert_json_orderless_equal({"flavors": {}}, payload)
 
     @responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_run_session_with_flavor(self):
         result = self.cli("record", "session", "--build", self.build_name,
                           "--flavor", "key=value", "--flavor", "k", "v", "--flavor", "k e y = v a l u e")
         self.assertEqual(result.exit_code, 0)
 
-        payload = json.loads(responses.calls[0].request.body)
+        payload = json.loads(responses.calls[0].request.body.decode())
         self.assert_json_orderless_equal({"flavors": {
             "key": "value",
             "k": "v",
