@@ -2,8 +2,10 @@ from pathlib import Path
 import responses  # type: ignore
 import json
 import gzip
+import os
 from launchable.utils.session import read_session
 from tests.cli_test_case import CliTestCase
+from unittest import mock
 
 
 class GoTestTest(CliTestCase):
@@ -11,6 +13,7 @@ class GoTestTest(CliTestCase):
         '../data/go_test/').resolve()
 
     @responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_subset_with_session(self):
         pipe = "TestExample1\nTestExample2\nTestExample3\nTestExample4\nok      github.com/launchableinc/rocket-car-gotest      0.268s"
         result = self.cli('subset', '--target', '10%',
@@ -24,6 +27,7 @@ class GoTestTest(CliTestCase):
         self.assert_json_orderless_equal(expected, payload)
 
     @responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_subset_without_session(self):
         pipe = "TestExample1\nTestExample2\nTestExample3\nTestExample4\nok      github.com/launchableinc/rocket-car-gotest      0.268s"
         result = self.cli('subset', '--target', '10%', '--build',
@@ -39,6 +43,7 @@ class GoTestTest(CliTestCase):
         self.assert_json_orderless_equal(expected, payload)
 
     @responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_record_tests_with_session(self):
         result = self.cli('record', 'tests',  '--session',
                           self.session, 'go-test', str(self.test_files_dir) + "/")
@@ -46,8 +51,7 @@ class GoTestTest(CliTestCase):
 
         self.assertIn(
             'events', responses.calls[1].request.url, 'call events API')
-        payload = json.loads(gzip.decompress(
-            b''.join(responses.calls[1].request.body)).decode())
+        payload = json.loads(gzip.decompress(responses.calls[1].request.body).decode())
         # Remove timestamp because it depends on the machine clock
         for c in payload['events']:
             del c['created_at']
@@ -60,6 +64,7 @@ class GoTestTest(CliTestCase):
             'close', responses.calls[2].request.url, 'call close API')
 
     @responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_record_tests_without_session(self):
         result = self.cli('record', 'tests', '--build',
                           self.build_name, 'go-test', str(self.test_files_dir) + "/")
@@ -69,8 +74,7 @@ class GoTestTest(CliTestCase):
 
         self.assertIn(
             'events', responses.calls[2].request.url, 'call events API')
-        payload = json.loads(gzip.decompress(
-            b''.join(responses.calls[2].request.body)).decode())
+        payload = json.loads(gzip.decompress(responses.calls[2].request.body).decode())
         for c in payload['events']:
             del c['created_at']
 
